#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 happstack-server
version:              7.9.3
visibility:           public
id:                   happstack-server-7.9.3-gP0sBFTRJF7JjgFHldDwI
key:                  happstack-server-7.9.3-gP0sBFTRJF7JjgFHldDwI
license:              BSD-3-Clause
maintainer:           Happstack team <happs@googlegroups.com>
author:               Happstack team, HAppS LLC
homepage:             http://happstack.com
synopsis:             Web related tools and services.
description:
    Happstack Server provides an HTTP server and a rich set of functions for routing requests, handling query parameters, generating responses, working with cookies, serving files, and more. For in-depth documentation see the Happstack Crash Course <http://happstack.com/docs/crashcourse/index.html>

category:             Web, Happstack
abi:                  22a4922134e991ad385b499688315b8b
exposed:              True
exposed-modules:
    Happstack.Server Happstack.Server.Auth Happstack.Server.Compression
    Happstack.Server.Cookie Happstack.Server.Error
    Happstack.Server.FileServe
    Happstack.Server.FileServe.BuildingBlocks Happstack.Server.I18N
    Happstack.Server.Internal.Compression
    Happstack.Server.Internal.Cookie Happstack.Server.Internal.Handler
    Happstack.Server.Internal.Listen
    Happstack.Server.Internal.LogFormat
    Happstack.Server.Internal.LowLevel
    Happstack.Server.Internal.MessageWrap
    Happstack.Server.Internal.Monads
    Happstack.Server.Internal.Multipart
    Happstack.Server.Internal.RFC822Headers
    Happstack.Server.Internal.Socket
    Happstack.Server.Internal.TimeoutIO
    Happstack.Server.Internal.TimeoutManager
    Happstack.Server.Internal.TimeoutSocket
    Happstack.Server.Internal.Types Happstack.Server.Monads
    Happstack.Server.Response Happstack.Server.Routing
    Happstack.Server.RqData Happstack.Server.SURI
    Happstack.Server.SimpleHTTP Happstack.Server.Types
    Happstack.Server.Validation

hidden-modules:
    Happstack.Server.Internal.Clock Happstack.Server.Internal.LazyLiner
    Happstack.Server.SURI.ParseURI Paths_happstack_server

import-dirs:          /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/happstack-server-7.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-happstack-server
hs-libraries:         HShappstack-server-7.9.3-gP0sBFTRJF7JjgFHldDwI
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-7Dsh2HoU9pUKnPpyGeO0o2
    blaze-html-0.9.2.0-B0rBYLjcB4OAeiMHew8PSj bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5 exceptions-0.10.7
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    filepath-1.4.300.1 hslogger-1.3.2.0-7AcHM45mZMX2XtopYkplB1
    html-1.0.1.2-yrvyqtjCXbBHvzYDYrrGC
    monad-control-1.0.3.1-7xrJc81SCp2JkhcpwQsEqa mtl-2.3.1
    network-3.1.4.0-F5hgFLxNbdiMTTF4ZJb4k
    network-uri-2.6.4.2-C6zcMal8NTtBaadlOrVMGP parsec-3.1.16.1
    process-1.6.19.0 sendfile-0.7.11.6-A51mxQSDuUOG2CunE7nZKe
    syb-0.7.3-GhxEKVO9aRZHddME5iK0hL
    system-filepath-0.4.14.1-Bbc8vgVo0BwJjDzLq0Beir text-2.0.2
    threads-0.5.1.8-2qeOWwOcBOM6HGKiicp2gF time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-8zuijaQKjxmHQR0gDCkKe4 unix-2.8.4.0
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1 xhtml-3000.2.2.1
    zlib-0.7.0.0-HmTetCetrgbCmH11uVpJkF

haddock-interfaces:
    /usr/share/doc/haskell-happstack-server/html/happstack-server.haddock

haddock-html:         /usr/share/doc/haskell-happstack-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

